#!/system/bin/sh

# set all output of this script to redirect to logcat
misty_log()
{
    log -p i -t "misty-init" "$@"
}

misty_log "Starting main Misty initialization script"

# Check sdcard for new scripts
while [ ! -d /sdcard ]
do
    misty_log "Waiting for sdcard..."
    sleep 5
done

if [ -e /sdcard/scripts.tar ]; then
    misty_log "Updating Misty scripts"

    # Delete and create backup directory.
    rm -r -f /data/misty/scriptsbackup
    mkdir /data/misty/scriptsbackup

    # May already exist.
    mkdir /data/misty/scripts

    misty_log "Copying scripts directory contents to scriptsbackup directory"
    cp -r /data/misty/scripts/* /data/misty/scriptsbackup

    misty_log "Clearing scripts directory"
    rm -r -f /data/misty/scripts/*
    retval=$?
    if [ $retval -ne 0 ]; then
        misty_log "Clear failed"
    fi
    if [ $retval -eq 0 ]; then
        misty_log "Copying tar file to scripts directory"
        cp /sdcard/scripts.tar /data/misty/scripts/scripts.tar
        retval=$?
        if [ $retval -ne 0 ]; then
            misty_log "Copy failed"
        fi
    fi
    if [ $retval -eq 0 ]; then
        misty_log "Unpacking tar file"
        tar -xf /data/misty/scripts/scripts.tar -C /data/misty/scripts/
        retval=$?
        if [ $retval -ne 0 ]; then
            misty_log "Unpack failed"
        fi
    fi
    if [ $retval -eq 0 ]; then
        misty_log "chmod scripts"
        chmod 755 /data/misty/scripts/*.sh
        retval=$?
        if [ $retval -ne 0 ]; then
            misty_log "chmod failed"
        fi
    fi
    if [ $retval -eq 0 ]; then
        misty_log "Deleting tar file from sdcard directory"
        rm /sdcard/scripts.tar
        retval=$?
        if [ $retval -ne 0 ]; then
            misty_log "Delete failed"
        fi
    fi
    if [ $retval -ne 0 ]; then
        misty_log "Failed to update scripts. Reverting to backedup scripts."
        cp -r /data/misty/scriptsbackup/* /data/misty/scripts
        if [ $? -ne 0 ]; then
            misty_log "Revert failed"
        fi
    fi

    # Delete tar file from scripts directory no matter what
    rm /data/misty/scripts/scripts.tar
fi

for filename in /data/misty/scripts/*.sh; do
    misty_log "Running "$filename
    "$filename" &
done

misty_log "Exiting main Misty initialization script"
